Crate anyxml_automata

Crate anyxml_automata 

Provides implementation of finite automata.

One goal is to provide content models in DTD element type declarations and regular expression implementations that conform to the XML Schema specification.

In addition, we provide an AST that expresses such regular expressions and a library that constructs finite automata from the AST. Users of the library can use these features to implement their own regular expression parsers.

Modules

ast
fa
unicode
Generated by generate-ast-for-unicode.ts
util
xsregexp
Implement the regular expressions described in XML Schema Part 2: Datatypes Second Edition Appendix F Regular Expressions.

Traits

Atom